ExtraSamples

Enum ExtraSamples 

#[non_exhaustive]
#[repr(u16)]
pub enum ExtraSamples { Unspecified = 0, AssociatedAlpha = 1, UnassociatedAlpha = 2, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspecified = 0

There is no specified association between the sample and the image.



AssociatedAlpha = 1

The sample is associated alpha, i.e. pre-multiplied color.



UnassociatedAlpha = 2

The sample is unassociated alpha such as a mask. There might be more than one such sample.

Implementations

Source

impl ExtraSamples

pub const fn from_u16(val: u16) -> Option<Self>

pub const fn to_u16(&self) -> u16