Predictor

Enum Predictor 

#[non_exhaustive]
#[repr(u16)]
pub enum Predictor { None = 1, Horizontal = 2, FloatingPoint = 3, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None = 1

No changes were made to the data



Horizontal = 2

The images’ rows were processed to contain the difference of each pixel from the previous one.

This means that instead of having in order [r1, g1. b1, r2, g2 ...] you will find [r1, g1, b1, r2-r1, g2-g1, b2-b1, r3-r2, g3-g2, ...]



FloatingPoint = 3

Not currently supported

Implementations

Source

impl Predictor

pub const fn from_u16(val: u16) -> Option<Self>

pub const fn to_u16(&self) -> u16