ValueBuffer

Struct ValueBuffer 

pub struct ValueBuffer { /* private fields */ }
A value represented as in-memory bytes with flexible byteorder.

Implementations

Source

impl ValueBuffer

pub fn empty(ty: Type) -> Self

A value with a count of zero.

The byte order is set to the native byte order of the platform.

pub fn from_value<T: TiffValue>(value: &T) -> Self

Create a value with native byte order from in-memory data.

pub fn byte_order(&self) -> ByteOrder

pub fn data_type(&self) -> Type

pub fn count(&self) -> u64

The count of items in the value.

pub fn as_bytes(&self) -> &[u8]

View the underlying raw bytes of this value.

pub fn as_bytes_mut(&mut self) -> &mut [u8]

View the underlying mutable raw bytes of this value.

pub fn set_byte_order(&mut self, byte_order: ByteOrder)

Change the byte order of the value representation.