pub enum ByteOrder {
LittleEndian,
BigEndian,
}Expand description
Byte order of the TIFF file.
Variants
Implementations
Sourceimpl ByteOrder
impl ByteOrder
Sourcepub const fn native() -> Self
pub const fn native() -> Self
Get the byte order representing the running target.
The infallibility of this method represents the fact that only little and big endian systems are supported by the library. No mixed endian and no other weird stuff. (Note: as of Rust 1.90 this is a tautology as Rust itself only has those two kinds).
Sourcepub fn convert(self, ty: Type, buffer: &mut [u8], to: ByteOrder)
pub fn convert(self, ty: Type, buffer: &mut [u8], to: ByteOrder)
Given a typed buffer, convert its contents to the specified byte order in-place.
The buffer is assumed to represent an array of the given type. If the length of the buffer is not divisible into an integer number of values, the behavior for the remaining bytes it not specified.